==> react-router-redux-4.0.56.tgz: react-router-redux v4.0/README.md <==
# Installation
> `npm install --save @types/react-router-redux`

# Summary
This package contains type definitions for react-router-redux (https://github.com/rackt/react-router-redux).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-router-redux/v4.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-router-redux/v4/index.d.ts)
````ts
// Type definitions for react-router-redux 4.0
// Project: https://github.com/rackt/react-router-redux
// Definitions by: Isman Usoh <https://github.com/isman-usoh>
//                 Noah Shipley <https://github.com/noah79>
//                 Karol Janyst <https://github.com/LKay>
//                 Dovydas Navickas <https://github.com/DovydasNavickas>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

import { History, Location, LocationDescriptor } from "history";
import { Action, Middleware, Store } from "redux";

export const CALL_HISTORY_METHOD: string;
export const LOCATION_CHANGE: string;

export interface LocationActionPayload {
    method: string;
    args?: any[] | undefined;
}

export interface RouterAction extends Action {
    payload?: LocationActionPayload | undefined;
}

export type LocationAction = (nextLocation: LocationDescriptor) => RouterAction;
export type GoAction = (n: number) => RouterAction;
export type NavigateAction = () => RouterAction;

export const push: LocationAction;
export const replace: LocationAction;
export const go: GoAction;
export const goBack: NavigateAction;
export const goForward: NavigateAction;

export interface RouteActions {
    push: typeof push;
    replace: typeof replace;
    go: typeof go;
    goForward: typeof goForward;
    goBack: typeof goBack;
}

export const routerActions: RouteActions;

export interface RouterState {
    locationBeforeTransitions: Location;
}

export type DefaultSelectLocationState = (state: any) => RouterState;

export interface SyncHistoryWithStoreOptions {
    selectLocationState?: DefaultSelectLocationState | undefined;
    adjustUrlOnReplay?: boolean | undefined;
}

export interface HistoryUnsubscribe {
    unsubscribe(): void;
}

export function routerReducer(state?: RouterState, action?: Action): RouterState;
export function syncHistoryWithStore(
    history: History,
    store: Store<any>,
    options?: SyncHistoryWithStoreOptions,
): History & HistoryUnsubscribe;
export function routerMiddleware(history: History): Middleware;

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/history](https://npmjs.com/package/@types/history), [@types/redux](https://npmjs.com/package/@types/redux)
 * Global values: none

# Credits
These definitions were written by [Isman Usoh](https://github.com/isman-usoh), [Noah Shipley](https://github.com/noah79), [Karol Janyst](https://github.com/LKay), and [Dovydas Navickas](https://github.com/DovydasNavickas).

==> react-router-redux-4.0.57.tgz: react-router-redux v4.0/README.md <==
# Installation
> `npm install --save @types/react-router-redux`

# Summary
This package contains type definitions for react-router-redux (https://github.com/rackt/react-router-redux).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-router-redux/v4.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-router-redux/v4/index.d.ts)
````ts
import { History, Location, LocationDescriptor } from "history";
import { Action, Middleware, Store } from "redux";

export const CALL_HISTORY_METHOD: string;
export const LOCATION_CHANGE: string;

export interface LocationActionPayload {
    method: string;
    args?: any[] | undefined;
}

export interface RouterAction extends Action {
    payload?: LocationActionPayload | undefined;
}

export type LocationAction = (nextLocation: LocationDescriptor) => RouterAction;
export type GoAction = (n: number) => RouterAction;
export type NavigateAction = () => RouterAction;

export const push: LocationAction;
export const replace: LocationAction;
export const go: GoAction;
export const goBack: NavigateAction;
export const goForward: NavigateAction;

export interface RouteActions {
    push: typeof push;
    replace: typeof replace;
    go: typeof go;
    goForward: typeof goForward;
    goBack: typeof goBack;
}

export const routerActions: RouteActions;

export interface RouterState {
    locationBeforeTransitions: Location;
}

export type DefaultSelectLocationState = (state: any) => RouterState;

export interface SyncHistoryWithStoreOptions {
    selectLocationState?: DefaultSelectLocationState | undefined;
    adjustUrlOnReplay?: boolean | undefined;
}

export interface HistoryUnsubscribe {
    unsubscribe(): void;
}

export function routerReducer(state?: RouterState, action?: Action): RouterState;
export function syncHistoryWithStore(
    history: History,
    store: Store<any>,
    options?: SyncHistoryWithStoreOptions,
): History & HistoryUnsubscribe;
export function routerMiddleware(history: History): Middleware;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 11:45:06 GMT
 * Dependencies: [@types/history](https://npmjs.com/package/@types/history), [redux](https://npmjs.com/package/redux)

# Credits
These definitions were written by [Isman Usoh](https://github.com/isman-usoh), [Noah Shipley](https://github.com/noah79), [Karol Janyst](https://github.com/LKay), and [Dovydas Navickas](https://github.com/DovydasNavickas).
